@@ -1,7 +1,7 @@
 ----------------------------------------------------------------------------
 -- @author koniu &lt;gkusnierz@gmail.com&gt;
 -- @copyright 2008 koniu
--- @release v3.4.13
+-- @release v3.4.14
 ----------------------------------------------------------------------------
 
 -- Package environment
@@ -30,7 +30,7 @@ module("naughty")
 -- @field padding Space between popups and edge of the workarea. Default: 4
 -- @field spacing Spacing between popups. Default: 1
 -- @field icon_dirs List of directories that will be checked by getIcon()
---   Default: { "/usr/share/pixmaps/", }
+--   Default: { "/usr/local/share/pixmaps/", }
 -- @field icon_formats List of formats that will be checked by getIcon()
 --   Default: { "png", "gif" }
 -- @field default_preset Preset to be used by default.
@@ -501,24 +501,23 @@ if capi.dbus then
                 -- icon_data is an array:
                 -- 1 -> width, 2 -> height, 3 -> rowstride, 4 -> has alpha
                 -- 5 -> bits per sample, 6 -> channels, 7 -> data
+                local width, height, rowstride = hints.icon_data[1], hints.icon_data[2], hints.icon_data[3]
 
                 local imgdata = ""
-                -- If has alpha (ARGB32)
-                if hints.icon_data[6] == 4 then
-                    for i = 1, #hints.icon_data[7], 4 do
+                local bpp = hints.icon_data[6]
+                local offset = 0
+                for y = 1, height do
+                    for i = 1 + offset, width * bpp + offset, bpp do
                         imgdata = imgdata .. hints.icon_data[7]:sub(i, i + 2):reverse()
-                        imgdata = imgdata .. hints.icon_data[7]:sub(i + 3, i + 3)
-                    end
-                -- If has not alpha (RGB24)
-                elseif hints.icon_data[6] == 3 then
-                    for i = 1, #hints.icon_data[7], 3 do
-                        imgdata = imgdata .. hints.icon_data[7]:sub(i , i + 2):reverse()
-                        imgdata = imgdata .. string.format("%c", 255) -- alpha is 255
+                        if bpp == 4 then
+                            imgdata = imgdata .. hints.icon_data[7]:sub(i + 3, i + 3)
+                        else
+                            imgdata = imgdata .. string.format("%c", 255)
+                        end
                     end
+                    offset = offset + rowstride
                 end
-                if imgdata then
-                    args.icon = capi.image.argb32(hints.icon_data[1], hints.icon_data[2], imgdata)
-                end
+                args.icon = capi.image.argb32(width, height, imgdata)
             end
             if replaces_id and replaces_id ~= "" and replaces_id ~= 0 then
                 args.replaces_id = replaces_id
